==> haskell-js-flot-0.8.3-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-js-flot.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: js-flot
version: 0.8.3
id: js-flot-0.8.3-FFINNwUg9vmHMMWQsN8uhg
key: js-flot-0.8.3-FFINNwUg9vmHMMWQsN8uhg
license: MIT
copyright: Neil Mitchell 2014
maintainer: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/js-flot#readme
synopsis: Obtain minified flot code
description:
    This package bundles the minified <http://www.flotcharts.org/ Flot> code
    (a jQuery plotting library) into a Haskell package,
    so it can be depended upon by Cabal packages. The first three components of
    the version number match the upstream flot version. The package is designed
    to meet the redistribution requirements of downstream users (e.g. Debian).
category: Javascript
author: Neil Mitchell <ndmitchell@gmail.com>
exposed: True
exposed-modules:
    Language.Javascript.Flot
hidden-modules: Paths_js_flot
abi: 8b506fbf693aa6d2970d0bfe2e592821
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/js-flot-0.8.3
library-dirs: /usr/lib/ghc-8.0.2/site-local/js-flot-0.8.3
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/js-flot-0.8.3
hs-libraries: HSjs-flot-0.8.3-FFINNwUg9vmHMMWQsN8uhg
depends:
    base-4.9.1.0
haddock-interfaces: /usr/share/doc/haskell-js-flot/html/js-flot.haddock
haddock-html: /usr/share/doc/haskell-js-flot/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-js-flot-0.8.3-5-i686.pkg.tar.xz: usr/share/haskell/register/haskell-js-flot.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: js-flot
version: 0.8.3
id: js-flot-0.8.3-JDUwO3yTt2e3BCiAqqIjur
key: js-flot-0.8.3-JDUwO3yTt2e3BCiAqqIjur
license: MIT
copyright: Neil Mitchell 2014
maintainer: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/js-flot#readme
synopsis: Obtain minified flot code
description:
    This package bundles the minified <http://www.flotcharts.org/ Flot> code
    (a jQuery plotting library) into a Haskell package,
    so it can be depended upon by Cabal packages. The first three components of
    the version number match the upstream flot version. The package is designed
    to meet the redistribution requirements of downstream users (e.g. Debian).
category: Javascript
author: Neil Mitchell <ndmitchell@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Language.Javascript.Flot
hidden-modules: Paths_js_flot
abi: 0cdac5fc80a85c6317508d2070b6fb1c
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/js-flot-0.8.3
library-dirs: /usr/lib/ghc-8.2.1/site-local/js-flot-0.8.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-js-flot
hs-libraries: HSjs-flot-0.8.3-JDUwO3yTt2e3BCiAqqIjur
depends:
    base-4.10.0.0
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
haddock-interfaces: /usr/share/doc/haskell-js-flot/html/js-flot.haddock
haddock-html: /usr/share/doc/haskell-js-flot/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
